@@ -208,7 +208,7 @@ class CacheClass(BaseCache):
         return result
 
     def _set(self, key, value, timeout, client, _add_only=False):
-        if timeout == 0:
+        if timeout is None or timeout == 0:
             if _add_only:
                 return client.setnx(key, value)
             return client.set(key, value)
@@ -231,12 +231,14 @@ class CacheClass(BaseCache):
         key = self.make_key(key, version=version)
         if timeout is DEFAULT_TIMEOUT:
             timeout = self.default_timeout
+        if timeout is not None:
+            timeout = int(timeout)
 
         # If ``value`` is not an int, then pickle it
         if not isinstance(value, int) or isinstance(value, bool):
-            result = self._set(key, pickle.dumps(value), int(timeout), client, _add_only)
+            result = self._set(key, pickle.dumps(value), timeout, client, _add_only)
         else:
-            result = self._set(key, value, int(timeout), client, _add_only)
+            result = self._set(key, value, timeout, client, _add_only)
         # result is a boolean
         return result
 
@@ -319,6 +321,18 @@ class CacheClass(BaseCache):
             self.set(key, value)
         return value
 
+    def ttl(self, key, version=None):
+        """
+        Returns the 'time-to-live' of a key.  If the key is not volitile, i.e.
+        it has not set expiration, then the value returned is None.  Otherwise,
+        the value is the number of seconds remaining.  If the key does not exist,
+        0 is returned.
+        """
+        key = self.make_key(key, version=version)
+        if self._client.exists(key):
+            return self._client.ttl(key)
+        return 0
+
 
 class RedisCache(CacheClass):
     """
@@ -335,7 +349,7 @@ class RedisCache(CacheClass):
         Adds delta to the cache version for the supplied key. Returns the
         new version.
 
-        Note: In Redis 2.0 you cannot rename a volitle key, so we have to move
+        Note: In Redis 2.0 you cannot rename a volitile key, so we have to move
         the value from the old key to the new key and maintain the ttl.
         """
         if version is None:
@@ -351,3 +365,4 @@ class RedisCache(CacheClass):
         self.set(new_key, value, timeout=ttl)
         self.delete(old_key)
         return version + delta
+
